A collection of useful utilities for computer vision in Python. 

Many of these functions came directly out of Stack Overflow answers that I've provided to add some otherwise missing functionality in OpenCV. Others come from me repeating something I tend to do often.

There's no core API that isn't prone to breaking on a whim.

OpenCV is not installed along with this package, you must install it yourself before using `cvtools`.

## Install
    
```sh
pip install cvtools-alkasm
```
